@@ -10,75 +10,6 @@ import ananimlib as al
 import numpy as np
 import copy as cp
 
-class Plot(al.CompositeAnObject):
-    """Plot a function
-    
-    Parameters
-    ----------
-    
-    size : optional, Vector
-        The size of the plot on the canvas.
-        default = same size as the plot area
-    
-    xrange : optional Vector        
-        The range of x-values to display
-        default = based on the range in the data.
-        
-    yrange : Vector
-        The range of y-values to display
-        default = based on the range in the data.
-        
-    title : str
-    xlabel : str
-    ylabel : str
-        The title and axis labels 
-    
-    """
-    
-    def __init__(self,data=None,size=None,
-                 xrange=None, yrange=None, 
-                 title=None,xlabel=None,ylabel=None,
-                 pen=None,):
-
-        super().__init__()
-        self.pen=pen
-        
-                
-        plot = al.CoordGrid([10,6], [5,16],[2,5],[.5,1],origin=[-2.5,4])
-        
-        self.add_anobject(plot,"plot")
-        self.new_curve(self.pen)
-        
-        if title is not None:
-            title=al.Text(title)
-            self.add_anobject(title)
-            title.position = [5.0,2.0]
-
-        if xlabel is not None:
-            xlabel = al.Text(xlabel)
-            self.add_anobject(xlabel)
-            xlabel.position = [5.0,0.3]
-            xlabel.scale=0.5
-
-    def new_curve(self, pen=None):
-        if pen is not None:
-            self.pen = pen
-        self.curve = al.BezierAnObject(pen=self.pen)
-        self["plot"].add_anobject(self.curve, preserve_transform=False)
-        
-    def update(self,time,timing):
-        
-        if timing.total_time_used > 0.02:
-            t = np.arange(0,timing.total_time_used,0.01)
-            
-            points = []
-            for t_ in t:
-                points.append(self.plot_func(t_))
-                
-            self.curve.data = al.PolyBezier()
-            pts = np.array([t,points]).transpose()
-            self.curve.data.connect_linear(pts)
-
 
 class CoordGrid(al.CompositeAnObject):
 
